.. image:: https://img.shields.io/pypi/v/mcrpc.svg
   :target: https://pypi.python.org/pypi/mcrpc/
   :alt: PyPI Status
.. image:: https://img.shields.io/pypi/l/mcrpc.svg
   :target: https://pypi.python.org/pypi/mcrpc/
   :alt: PyPI License


mcrpc: Multichain RPC Client
============================

* Free software: GNU General Public License v3
